@@ -36,6 +36,13 @@ GType gth_file_view_renderer_type_get_type (void);
 /* enumerations from "gth-filter.h" */
 GType gth_limit_type_get_type (void);
 #define GTH_TYPE_LIMIT_TYPE (gth_limit_type_get_type())
+/* enumerations from "gth-grid-view.h" */
+GType gth_cursor_movement_get_type (void);
+#define GTH_TYPE_CURSOR_MOVEMENT (gth_cursor_movement_get_type())
+GType gth_drop_position_get_type (void);
+#define GTH_TYPE_DROP_POSITION (gth_drop_position_get_type())
+GType gth_selection_change_get_type (void);
+#define GTH_TYPE_SELECTION_CHANGE (gth_selection_change_get_type())
 /* enumerations from "gth-histogram.h" */
 GType gth_histogram_channel_get_type (void);
 #define GTH_TYPE_HISTOGRAM_CHANNEL (gth_histogram_channel_get_type())
@@ -67,6 +74,8 @@ GType gth_check_type_get_type (void);
 GType gth_check_size_get_type (void);
 #define GTH_TYPE_CHECK_SIZE (gth_check_size_get_type())
 /* enumerations from "gth-metadata.h" */
+GType gth_metadata_type_get_type (void);
+#define GTH_TYPE_METADATA_TYPE (gth_metadata_type_get_type())
 GType gth_metadata_flags_get_type (void);
 #define GTH_TYPE_METADATA_FLAGS (gth_metadata_flags_get_type())
 /* enumerations from "gth-metadata-provider.h" */
@@ -95,6 +104,9 @@ GType gth_test_data_type_get_type (void);
 /* enumerations from "gth-user-dir.h" */
 GType gth_dir_get_type (void);
 #define GTH_TYPE_DIR (gth_dir_get_type())
+/* enumerations from "gtk-utils.h" */
+GType gth_action_flags_get_type (void);
+#define GTH_TYPE_ACTION_FLAGS (gth_action_flags_get_type())
 /* enumerations from "pixbuf-cache.h" */
 GType pixbuf_cache_channel_get_type (void);
 #define GTH_TYPE_CACHE_CHANNEL (pixbuf_cache_channel_get_type())
