@@ -6,7 +6,23 @@
 
 G_BEGIN_DECLS
 
-/* VOID:BOOLEAN,POINTER (./gth-marshal.list:1) */
+/* BOOLEAN:ENUM,ENUM (./gth-marshal.list:1) */
+extern void gth_marshal_BOOLEAN__ENUM_ENUM (GClosure     *closure,
+                                            GValue       *return_value,
+                                            guint         n_param_values,
+                                            const GValue *param_values,
+                                            gpointer      invocation_hint,
+                                            gpointer      marshal_data);
+
+/* BOOLEAN:VOID (./gth-marshal.list:2) */
+extern void gth_marshal_BOOLEAN__VOID (GClosure     *closure,
+                                       GValue       *return_value,
+                                       guint         n_param_values,
+                                       const GValue *param_values,
+                                       gpointer      invocation_hint,
+                                       gpointer      marshal_data);
+
+/* VOID:BOOLEAN,POINTER (./gth-marshal.list:3) */
 extern void gth_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -14,7 +30,15 @@ extern void gth_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* VOID:ENUM,ENUM (./gth-marshal.list:2) */
+/* VOID:BOXED,BOXED (./gth-marshal.list:4) */
+extern void gth_marshal_VOID__BOXED_BOXED (GClosure     *closure,
+                                           GValue       *return_value,
+                                           guint         n_param_values,
+                                           const GValue *param_values,
+                                           gpointer      invocation_hint,
+                                           gpointer      marshal_data);
+
+/* VOID:ENUM,ENUM (./gth-marshal.list:5) */
 extern void gth_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -22,7 +46,7 @@ extern void gth_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
 
-/* VOID:INT,INT (./gth-marshal.list:3) */
+/* VOID:INT,INT (./gth-marshal.list:6) */
 extern void gth_marshal_VOID__INT_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -30,7 +54,7 @@ extern void gth_marshal_VOID__INT_INT (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* VOID:OBJECT,BOOLEAN (./gth-marshal.list:4) */
+/* VOID:OBJECT,BOOLEAN (./gth-marshal.list:7) */
 extern void gth_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -38,7 +62,7 @@ extern void gth_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:OBJECT,BOXED,ENUM (./gth-marshal.list:5) */
+/* VOID:OBJECT,BOXED,ENUM (./gth-marshal.list:8) */
 extern void gth_marshal_VOID__OBJECT_BOXED_ENUM (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -46,7 +70,7 @@ extern void gth_marshal_VOID__OBJECT_BOXED_ENUM (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:OBJECT,BOXED,INT,ENUM (./gth-marshal.list:6) */
+/* VOID:OBJECT,BOXED,INT,ENUM (./gth-marshal.list:9) */
 extern void gth_marshal_VOID__OBJECT_BOXED_INT_ENUM (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
@@ -54,7 +78,7 @@ extern void gth_marshal_VOID__OBJECT_BOXED_INT_ENUM (GClosure     *closure,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT (./gth-marshal.list:7) */
+/* VOID:OBJECT,OBJECT (./gth-marshal.list:10) */
 extern void gth_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -62,7 +86,7 @@ extern void gth_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT,INT,INT,POINTER (./gth-marshal.list:8) */
+/* VOID:OBJECT,OBJECT,INT,INT,POINTER (./gth-marshal.list:11) */
 extern void gth_marshal_VOID__OBJECT_OBJECT_INT_INT_POINTER (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -70,7 +94,7 @@ extern void gth_marshal_VOID__OBJECT_OBJECT_INT_INT_POINTER (GClosure     *closu
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
 
-/* VOID:OBJECT,POINTER (./gth-marshal.list:9) */
+/* VOID:OBJECT,POINTER (./gth-marshal.list:12) */
 extern void gth_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -78,7 +102,7 @@ extern void gth_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:OBJECT,STRING (./gth-marshal.list:10) */
+/* VOID:OBJECT,STRING (./gth-marshal.list:13) */
 extern void gth_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -86,7 +110,7 @@ extern void gth_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:OBJECT,UINT (./gth-marshal.list:11) */
+/* VOID:OBJECT,UINT (./gth-marshal.list:14) */
 extern void gth_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -94,7 +118,7 @@ extern void gth_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER (./gth-marshal.list:12) */
+/* VOID:POINTER,POINTER (./gth-marshal.list:15) */
 extern void gth_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -102,7 +126,7 @@ extern void gth_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* VOID:STRING,STRING,BOOLEAN,DOUBLE (./gth-marshal.list:13) */
+/* VOID:STRING,STRING,BOOLEAN,DOUBLE (./gth-marshal.list:16) */
 extern void gth_marshal_VOID__STRING_STRING_BOOLEAN_DOUBLE (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
